package p;
class A{
	private int a;
	public A(int a) {
		this.a = a;
	}
}
class B extends Z{
	public B(int a, int b) {
		super(4, a, b);
	}
}
